.. _downloading_a_dataset_ref:
.. currentmodule:: skrub.datasets

Downloading a dataset
=====================

.. autosummary::
   :toctree: generated/
   :template: function.rst
   :nosignatures:

   fetch_employee_salaries
   fetch_medical_charge
   fetch_midwest_survey
   fetch_open_payments
   fetch_road_safety
   fetch_traffic_violations
   fetch_drug_directory
   fetch_world_bank_indicator
   fetch_movielens
   fetch_ken_table_aliases
   fetch_ken_types
   fetch_ken_embeddings
   make_deduplication_data
